UserRequest class

Inheritance

Constructors

UserRequest(String userId, Map<String, String> data, Map<String, List> multiData)

Properties

data ↔ Map<String, String>
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
multiData ↔ Map<String, List>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited