FormattedExperimentApiResponse class

Constructors

FormattedExperimentApiResponse({required Map<String, UserExperimentVariant> experimentData, String? experimentUserType, required int timestamp})
FormattedExperimentApiResponse.fromJson(Map<String, dynamic> json)
factory

Properties

experimentData → Map<String, UserExperimentVariant>
final
experimentUserType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

empty ↔ FormattedExperimentApiResponse
getter/setter pair