Session class

Constructors

Session({required String sessionId, required int sessionStartTs, required int lastCachedTs, required String startEvent, required String endEvent})
Session.fromJson(Map<String, dynamic> json)
factory
Session.newSession({required int createdTs, required String event})
factory

Properties

endEvent ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastCachedTs ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String
getter/setter pair
sessionStartTs ↔ int
getter/setter pair
startEvent ↔ String
getter/setter pair

Methods

copyWith({int? cachedTs, String? endEventName}) → Session
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited