MethodChannelPerceptFlutter class

An implementation of PerceptFlutterPlatform that uses method channels.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture() → Future<bool?>
Captures something.
inherited
clear() → Future<bool?>
Clears data.
override
getGlobalProperties() → Future<Map<String, String>?>
Retrieves global properties.
override
getPluginVersion() → String
get plugin version
override
getSdkType() → String
ger sdk type
inherited
getStaleExperimentInfo() → Future<String?>
Retrieves the experiment info
override
getUniqueID() → Future<String?>
Retrieves a unique ID.
override
getUserId() → Future<String?>
Retrieves the user ID.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGlobalProperties(Map<String, String>? globalProperties) → Future<bool?>
Sets global properties.
override
setStaleExperimentInfo(String experimentInfo) → Future<bool?>
Sets the experiment info
override
setUserId(String userId) → Future<bool?>
Sets the user ID.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited