PerceptFlutterPlatform class abstract

Abstract class defining the platform interface for PerceptFlutterPlugin.

Inheritance
  • Object
  • PlatformInterface
  • PerceptFlutterPlatform
Implementers

Constructors

PerceptFlutterPlatform()
Constructs a PerceptFlutterPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture() → Future<bool?>
Captures something.
clear() → Future<bool?>
Clears data.
getGlobalProperties() → Future<Map<String, String>?>
Retrieves global properties.
getPluginVersion() → String
get plugin version
getSdkType() → String
ger sdk type
getStaleExperimentInfo() → Future<String?>
Retrieves the experiment info
getUniqueID() → Future<String?>
Retrieves a unique ID.
getUserId() → Future<String?>
Retrieves the user ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setGlobalProperties(Map<String, String>? globalProperties) → Future<bool?>
Sets global properties.
setStaleExperimentInfo(String experimentInfo) → Future<bool?>
Sets the experiment info
setUserId(String userId) → Future<bool?>
Sets the user ID.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ PerceptFlutterPlatform
The default instance of PerceptFlutterPlatform to use. Defaults to MethodChannelPerceptFlutter.
getter/setter pair