PerceptFlutterWeb class

A web implementation of the PerceptFlutterPlatform of the PerceptFlutter plugin.

Inheritance

Constructors

PerceptFlutterWeb()
Constructs a PerceptFlutterWeb

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

capture() → Future<bool?>
Captures something.
inherited
clear() → Future<bool?>
Clears data.
override
getAllItemsWithNamespace(String namespace) → Map<String, String>
getGlobalProperties() → Future<Map<String, String>?>
Retrieves global properties.
override
getLocal(String name) → String?
getPluginVersion() → String
get plugin version
inherited
getSdkType() → String
ger sdk type
inherited
getStaleExperimentInfo() → Future<String?>
Retrieves the experiment info
override
getUniqueID() → Future<String?>
Retrieves a unique ID.
override
getUserId() → Future<String?>
Retrieves the user ID.
override
isLocalStorageSupported() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeLocal(String name) → void
saveLocal(Map<String, dynamic> data) → void
setGlobalProperties(Map<String, String>? globalProperties) → Future<bool?>
Sets global properties.
override
setStaleExperimentInfo(String experimentInfo) → Future<bool?>
Sets the experiment info
override
setUserId(String userId) → Future<bool?>
Sets the user ID.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void

Constants

experimentINFO → const String
namespace → const String
uniqueID → const String
userID → const String