TrackingDataProvider class

Properties

appname ↔ String
getter/setter pair
appversion ↔ String
getter/setter pair
configManager → ConfigManager
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionManager → SessionManager
final

Methods

captureSession(Session session) → Future<void>
getCommonTrackingData() → Future<Map<String, dynamic>>
getSessionProps(String token, String eventName) → Future<Map<String, dynamic>>
getUniqueProps({bool isCommRequest = false}) → Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → TrackingDataProvider
no setter