ExperimentService class

Constructors

ExperimentService({required String token, required bool isExperimentEnabled, Future<String?> getUniqueId()?, Future<String?> getUserId()?, Function? experimentFetchedCb, int? experimentRefetchIntervalMin})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance → ExperimentService
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempEventQueue ↔ List<Map<String, dynamic>>
getter/setter pair

Methods

addEvent(String name, Map<String, dynamic> properties) → void
clearRefetchTimer() → void
fetchExperimentData() → Future<FormattedExperimentApiResponse?>
getAllActiveExperiments() → Future<List<UserExperimentVariant>>
getExperiment(String experimentName) → Future<UserExperimentVariant?>
getExperimentProperties() → Map<String, dynamic>
getExperimentUserType() → Future<String?>
getIsExperimentDataResolved() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited