RetryScheduler class

Constructors

RetryScheduler({required String token, required dynamic maxBatchSize, required dynamic maxDelayInMs, required dynamic maxCacheSizeBytes, required dynamic clearAfterInMs, int thresholdInMs = 2000, int maxRetryCount = 1})
factory

Properties

batchedEventRequests ↔ List<EventRequest>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestCacher → RequestCacher
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDuplicates(List<EventRequest> eventRequests) → List<EventRequest>
schedule() → void
scheduleCommRequest(CommunicationRequest commRequest) → Future<void>
scheduleEventRequest(EventRequest eventRequest) → Future<void>
scheduleUserRequest(UserRequest userRequest) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → RetryScheduler
no setter